@@ -1,5 +1,5 @@
-import dotscanner.dataprocessing as dp
-import dotscanner.density as density
+import src.dataprocessing as dp
+import src.density as density
 import numpy as np
 import unittest
 
@@ -49,7 +49,7 @@ class TestDensity(unittest.TestCase):
 		}
 		
 		dotTotal, blobTotal, _, _ = density.getTotalsAndCoords(coordsInPolygon, dotCoords, 
-																blobCoords, blobSize=5)
+			blobCoords, blobSize=5)
 		
 		self.assertEqual(dotTotal, 1)
 		self.assertEqual(blobTotal, 4)
@@ -64,7 +64,7 @@ class TestDensity(unittest.TestCase):
 		}
 		
 		dotTotal, blobTotal, _, _ = density.getTotalsAndCoords(coordsInPolygon, dotCoords, 
-																blobCoords, blobSize=5)
+			blobCoords, blobSize=5)
 		
 		self.assertEqual(dotTotal, 2)
 		self.assertEqual(blobTotal, 5)
